@@ -5,7 +5,7 @@ const QString iconSilent = "/usr/share/icons/hicolor/48x48/hildon/statusarea_sil
 const QString iconGeneral = "/usr/share/icons/hicolor/48x48/hildon/statusarea_volumelevel4.png";
 
 ProfileChangerWidget::ProfileChangerWidget (QWidget *parent) :
-QMainWindow(parent),
+QMainWindow(parent, Qt::FramelessWindowHint),
     ui(new Ui::ProfileChangerWidget)
 {
     ui->setupUi(this);
@@ -15,11 +15,12 @@ QMainWindow(parent),
     ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
     palette.setColor(QPalette::Base, Qt::transparent);
     ui->centralWidget->setPalette(palette);
+    ui->switchButton->setPalette(palette);
     QSettings settings;
     if (!settings.contains("profilechangerwidget/width"))
-        settings.setValue("profilechangerwidget/width", 48);
+        settings.setValue("profilechangerwidget/width", 96);
     if (!settings.contains("profilechangerwidget/height"))
-        settings.setValue("profilechangerwidget/height", 48);
+        settings.setValue("profilechangerwidget/height", 96);
 
     connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
     this->reloadSettings();
