@@ -1,5 +1,6 @@
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
+#include <QLibraryInfo>
 
 SettingsDialog::SettingsDialog(QWidget *parent) :
     QDialog(parent),
@@ -36,6 +37,7 @@ void SettingsDialog::accept()
 
 void SettingsDialog::showAbout()
 {
+    QMaemo5InformationBox::information(this, QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     QDialog *aboutDialog = new QDialog(0);
     aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
     aboutDialog->setWindowTitle(tr("About Profile Changer Widget"));
